@@ -169,7 +169,8 @@ def get_existing_keywords(googleads_client,customer_id):
           ad_group_criterion.keyword.match_type,
           ad_group_criterion.status
         FROM ad_group_criterion       
-        WHERE ad_group_criterion.type = KEYWORD AND campaign.status IN ('ENABLED', 'PAUSED')"""
+        WHERE ad_group_criterion.type = KEYWORD AND campaign.status IN ('ENABLED', 'PAUSED') 
+        AND ad_group.status IN ('ENABLED', 'PAUSED') """
 
     search_request = googleads_client.get_type("SearchGoogleAdsRequest")
     search_request.customer_id = customer_id
@@ -448,7 +449,9 @@ def get_all_ads(client,customer_id):
     query = """
     SELECT
     ad_group.id,
+    ad_group.status,
     campaign.id,
+    campaign.status,
     ad_group_ad.ad.id,
     ad_group_ad.ad.responsive_search_ad.headlines,
     ad_group_ad.ad.responsive_search_ad.descriptions,
@@ -457,12 +460,15 @@ def get_all_ads(client,customer_id):
     ad_group_ad.ad.responsive_search_ad.path2,
     ad_group_ad.status
     FROM ad_group_ad
-    WHERE ad_group_ad.ad.type = RESPONSIVE_SEARCH_AD
+    WHERE ad_group_ad.ad.type = RESPONSIVE_SEARCH_AD AND campaign.status IN ('ENABLED', 'PAUSED')
+    AND ad_group.status IN ('ENABLED', 'PAUSED')
     """
 
     df_dict = {
         'adgroup_id': list(),
         'campaign_id': list(),
+        'adgroup_status':list(),
+        'campaign_status':list(),
         'adgroup_ad_id': list(),
         'headline_keywords': list(),
         'ad_description': list(),
@@ -494,6 +500,8 @@ def get_all_ads(client,customer_id):
 
             df_dict['adgroup_id'].append(adgroup.id)
             df_dict['campaign_id'].append(campaign.id)
+            df_dict['campaign_status'].append(campaign.status.name)
+            df_dict['adgroup_status'].append(adgroup.status.name)
             df_dict['adgroup_ad_id'].append(adgroup_ad.ad.id)
             df_dict['headline_keywords'].append(temp)
             df_dict['ad_description'].append(temp2)
